Package: tidycmprsk
Title: Competing Risks Estimation
Version: 1.1.2
Authors@R: c(
    person(c("Daniel", "D."), "Sjoberg", , "danield.sjoberg@gmail.com", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0003-0862-2018")),
    person("Teng", "Fei", role = "aut",
           comment = c(ORCID = "0000-0001-7888-1715"))
  )
Description: Provides an intuitive interface for working with the
    competing risk endpoints. The package wraps the 'cmprsk' package, and
    exports functions for univariate cumulative incidence estimates and
    competing risk regression. Methods follow those introduced in Fine and
    Gray (1999) <doi:10.1002/sim.7501>.
License: AGPL (>= 3)
URL: https://mskcc-epi-bio.github.io/tidycmprsk/,
        https://github.com/MSKCC-Epi-Bio/tidycmprsk
BugReports: https://github.com/MSKCC-Epi-Bio/tidycmprsk/issues
Depends: R (>= 4.2)
Imports: broom (>= 1.0.1), cli, cmprsk (>= 2.2.10), dplyr, ggplot2 (>=
        3.3.5), gtsummary (>= 2.0.0), hardhat (>= 1.3.0), purrr (>=
        0.3.4), rlang, stringr (>= 1.4.0), survival, tibble (>= 3.1.6),
        tidyr
Suggests: aod, broom.helpers (>= 1.15.0), cardx (>= 0.2.0), covr (>=
        3.5.1), ggsurvfit, knitr (>= 1.36), spelling, testthat (>=
        3.2.0)
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-04-09 03:42:35 UTC; sjobergd
Author: Daniel D. Sjoberg [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0003-0862-2018>),
  Teng Fei [aut] (ORCID: <https://orcid.org/0000-0001-7888-1715>)
Maintainer: Daniel D. Sjoberg <danield.sjoberg@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-09 05:10:02 UTC
Built: R 4.6.0; ; 2026-04-30 22:18:52 UTC; unix
