# dplyr ------------------------------------------------------------------------
#' @export
#' @importFrom dplyr %>%
dplyr::`%>%`

# survival ---------------------------------------------------------------------
#' @export
#' @importFrom survival Surv
survival::Surv

# ggplot2 ----------------------------------------------------------------------
#' @export
#' @importFrom ggplot2 autoplot
ggplot2::autoplot

# broom ------------------------------------------------------------------------
#' @export
#' @importFrom broom tidy
broom::tidy

#' @export
#' @importFrom broom glance
broom::glance

#' @export
#' @importFrom broom augment
broom::augment

# gtsummary --------------------------------------------------------------------
#' @export
#' @importFrom gtsummary tbl_regression
gtsummary::tbl_regression

#' @export
#' @importFrom gtsummary global_pvalue_fun
gtsummary::global_pvalue_fun

#' @export
#' @importFrom gtsummary add_n
gtsummary::add_n

#' @export
#' @importFrom gtsummary add_nevent
gtsummary::add_nevent

#' @export
#' @importFrom gtsummary add_p
gtsummary::add_p

#' @export
#' @importFrom gtsummary inline_text
gtsummary::inline_text


